@@ -156,15 +156,11 @@ function loadWithCache(code) {
 
 if (process.browser) {
   op.loadbytecode = /*async*/ function(ctx, file) {
-      if (file == 'Perl6/BOOTSTRAP.js') {
-        file = 'Perl6::BOOTSTRAP';
-      }
-
       const oldLoaderCtx = exports.loaderCtx;
       exports.loaderCtx = ctx;
       file = file.replace(/\./g, '_');
       file = file.replace(/\_js$/, '');
-      file = file.replace(/::/g, '-');
+      file = file.replace(/::/g, '/');
       /*await*/ loadWithCache(require('./' + file + '.nqp-raw-runtime'));
       exports.loaderCtx = oldLoaderCtx;
   };
@@ -174,11 +170,6 @@ if (process.browser) {
   };
 } else {
   op.loadbytecode = /*async*/ function(ctx, file) {
-    // HACK - temporary hack for rakudo-js
-    if (file == 'Perl6/BOOTSTRAP.js') {
-      file = 'Perl6::BOOTSTRAP';
-    }
-
     let loadFrom;
     if (ctx && ((loadFrom = ctx.lookupDynamic('$*LOADBYTECODE_FROM')) !== Null)) {
     } else {
@@ -187,7 +178,7 @@ if (process.browser) {
 
     const oldLoaderCtx = exports.loaderCtx;
     exports.loaderCtx = ctx;
-    const mangled = file.replace(/::/g, '-');
+    const mangled = file.replace(/::/g, '/');
 
     const prefixes = libpath.slice();
 
@@ -490,7 +481,7 @@ exports.createIntArray = require('./BOOT.js').createIntArray;
 
 const containerSpecs = require('./container-specs.js');
 exports.extraRuntime = function(lang, path) {
-  if (lang != 'perl6') throw 'only loading extra runtime for perl 6 is supported';
+  if (lang != 'Raku') throw 'only loading extra runtime for Raku is supported';
   const runtime = typeof path === 'string' ? require(path) : path.require(lang + '-runtime');
   if (!runtime.loaded) {
     runtime.loaded = true;
